# ROUTINES

This folder introduces the concept of routines, which are meant for the user to develop and run at once. The notebook reports is a better approach to this idea, but currently the development of this is not trivial. On the other hand, the development of this is trivial as long as the user is familiar with our terminal interface.

Try out with:

```bash
python terminal.py routines/example.openbb
```

Or within the Terminal, use:

```bash
exe routines/example.openbb
```
